@@ -11,6 +11,7 @@ BSE_HOLIDAYS = ['2018-01-26', '2018-02-13', '2018-03-02', '2018-03-29',
                 '2018-02-19', '2018-04-30', '2018-08-17', '2018-11-21']
 
 MF_ALLOTMENT_TAT = {
+    'Default': [0, 1],
     'F309-GR': [0, 2],
     '410-GR': [0, 2],
     'RELLFTPI-GR': [1, 0],
@@ -19,4 +20,5 @@ MF_ALLOTMENT_TAT = {
     'EDGCGP-GR': [0, 1],
     'CPGP-GR': [0, 1],
     'CREQGP-GR': [0, 1],
+    'RELRSFB-GR': [0, 1]
 }
\ No newline at end of file
